==> haskell-rio-orphans-0.1.2.0-341-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-E749ve77R9l3cikVPXYIzv
key:                  rio-orphans-0.1.2.0-E749ve77R9l3cikVPXYIzv
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  e5cb36f8ed4675f79f62e2a25f8052d9
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-E749ve77R9l3cikVPXYIzv
depends:
    base-4.16.4.0 exceptions-0.10.4
    fast-logger-3.1.2-Fa3Fla0vL96F1yUuo0wPh3
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2
    monad-logger-0.3.41-8zyVgcqpPx43KkKgWZv8tk
    resourcet-1.2.6-7XRvu1GZSDsLOgaXXocelp
    rio-0.1.22.0-HslMAxv3Fe49YqeGmiLusl
    transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.2.0-342-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-D6a0a06P6ocDz4FcM3VosD
key:                  rio-orphans-0.1.2.0-D6a0a06P6ocDz4FcM3VosD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  9321efd0a5a505a36465db88942244ff
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-D6a0a06P6ocDz4FcM3VosD
depends:
    base-4.16.4.0 exceptions-0.10.4
    fast-logger-3.1.2-G8MJ4B7wU8gBkZ1rQwpl8w
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2
    monad-logger-0.3.41-Col3X0GV1il77hbKdWgSEC
    resourcet-1.2.6-7XRvu1GZSDsLOgaXXocelp
    rio-0.1.22.0-GUvRq0hBYoF89KEi9ACIN0
    transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
